# Change Log

## [4.2.2](https://github.com/jpmonette/feed/tree/4.2.2) (2021-01-22)
[Full Changelog](https://github.com/jpmonette/feed/compare/4.2.1...4.2.2)

**Implemented enhancements:**

- Export types in feed [\#128](https://github.com/jpmonette/feed/issues/128)

**Merged pull requests:**

- Bump node-notifier from 8.0.0 to 8.0.1 [\#137](https://github.com/jpmonette/feed/pull/137) ([dependabot[bot]](https://github.com/apps/dependabot))
- fix: export types from feed [\#136](https://github.com/jpmonette/feed/pull/136) ([gustavkj](https://github.com/gustavkj))
- Bump deps [\#129](https://github.com/jpmonette/feed/pull/129) ([jpmonette](https://github.com/jpmonette))
- Bump lodash from 4.17.15 to 4.17.19 [\#127](https://github.com/jpmonette/feed/pull/127) ([dependabot[bot]](https://github.com/apps/dependabot))

## [4.2.1](https://github.com/jpmonette/feed/tree/4.2.1) (2020-07-05)
[Full Changelog](https://github.com/jpmonette/feed/compare/4.2.0...4.2.1)

**Closed issues:**

- RSS pubDate set to "date" rather than "published", unlike Atom [\#117](https://github.com/jpmonette/feed/issues/117)

**Merged pull requests:**

- Sanitizing XML feeds [\#125](https://github.com/jpmonette/feed/pull/125) ([decebal](https://github.com/decebal))
- author.uri and author.email should be optional in atom \#115 [\#124](https://github.com/jpmonette/feed/pull/124) ([decebal](https://github.com/decebal))
- fix: 🐛 overwrite pubDate on rss when published is specified [\#121](https://github.com/jpmonette/feed/pull/121) ([decebal](https://github.com/decebal))

## [4.2.0](https://github.com/jpmonette/feed/tree/4.2.0) (2020-05-25)
[Full Changelog](https://github.com/jpmonette/feed/compare/4.1.0...4.2.0)

**Closed issues:**

- Getting an error during Netlify deploy \(and npm run build\) [\#118](https://github.com/jpmonette/feed/issues/118)
- atom:link in RSS feed should point to self, not atom [\#113](https://github.com/jpmonette/feed/issues/113)

**Merged pull requests:**

- Update dependencies + Formatting + Add Comments [\#123](https://github.com/jpmonette/feed/pull/123) ([jpmonette](https://github.com/jpmonette))
- fix: 🐛 atom link needs to point to self [\#122](https://github.com/jpmonette/feed/pull/122) ([decebal](https://github.com/decebal))
- feat: 🎸 add mandatory rss2 attributes on enclosure [\#120](https://github.com/jpmonette/feed/pull/120) ([decebal](https://github.com/decebal))
- Bump acorn from 5.7.3 to 5.7.4 [\#116](https://github.com/jpmonette/feed/pull/116) ([dependabot[bot]](https://github.com/apps/dependabot))

## [4.1.0](https://github.com/jpmonette/feed/tree/4.1.0) (2019-12-29)
[Full Changelog](https://github.com/jpmonette/feed/compare/4.0.0...4.1.0)

**Closed issues:**

- Update the default of date on atom to be published [\#108](https://github.com/jpmonette/feed/issues/108)
- export base xml-js object [\#102](https://github.com/jpmonette/feed/issues/102)
- Add extra attributes on \<rss\> tag [\#98](https://github.com/jpmonette/feed/issues/98)
- item.id is ignored in rss output [\#96](https://github.com/jpmonette/feed/issues/96)
- How to generate \<dc:creator\> [\#90](https://github.com/jpmonette/feed/issues/90)
- Specify namespace and custom attributes [\#88](https://github.com/jpmonette/feed/issues/88)

**Merged pull requests:**

- Bump handlebars from 4.1.2 to 4.5.3 [\#110](https://github.com/jpmonette/feed/pull/110) ([dependabot[bot]](https://github.com/apps/dependabot))
- Item category for all feed types [\#109](https://github.com/jpmonette/feed/pull/109) ([mattimbrain](https://github.com/mattimbrain))
- Bump lodash from 4.17.11 to 4.17.15 [\#106](https://github.com/jpmonette/feed/pull/106) ([dependabot[bot]](https://github.com/apps/dependabot))
- Fix RSS ignoring item.id [\#105](https://github.com/jpmonette/feed/pull/105) ([ArtskydJ](https://github.com/ArtskydJ))
- Change default RSS docs url + Allow docs override [\#97](https://github.com/jpmonette/feed/pull/97) ([sonniesedge](https://github.com/sonniesedge))

## [4.0.0](https://github.com/jpmonette/feed/tree/4.0.0) (2019-07-06)
[Full Changelog](https://github.com/jpmonette/feed/compare/3.0.0...4.0.0)

**Merged pull requests:**

- Push to 4.0.0 [\#95](https://github.com/jpmonette/feed/pull/95) ([jpmonette](https://github.com/jpmonette))
- Update homepage to github repo [\#92](https://github.com/jpmonette/feed/pull/92) ([kevinsimper](https://github.com/kevinsimper))

## [3.0.0](https://github.com/jpmonette/feed/tree/3.0.0) (2019-05-28)
[Full Changelog](https://github.com/jpmonette/feed/compare/2.0.4...3.0.0)

**Merged pull requests:**

- Migrate from xml to xml-js [\#93](https://github.com/jpmonette/feed/pull/93) ([jpmonette](https://github.com/jpmonette))
- Migrate from xml to xml-js [\#91](https://github.com/jpmonette/feed/pull/91) ([jpmonette](https://github.com/jpmonette))

## [2.0.4](https://github.com/jpmonette/feed/tree/2.0.4) (2019-03-02)
[Full Changelog](https://github.com/jpmonette/feed/compare/2.0.0...2.0.4)

**Implemented enhancements:**

- Feed support for Category on Items [\#71](https://github.com/jpmonette/feed/issues/71)

**Closed issues:**

- TypeError: Feed is not a constructor [\#80](https://github.com/jpmonette/feed/issues/80)
- Example Code, `posts` Undefined [\#78](https://github.com/jpmonette/feed/issues/78)
- npm package broken [\#77](https://github.com/jpmonette/feed/issues/77)
- Cannot display the publish time of essay correctly. [\#67](https://github.com/jpmonette/feed/issues/67)
- Feedly.com not accepting it [\#62](https://github.com/jpmonette/feed/issues/62)
- TypeError: d.getUTCFullYear is not a function [\#59](https://github.com/jpmonette/feed/issues/59)
- Extra properties [\#57](https://github.com/jpmonette/feed/issues/57)
- Support paged feeds [\#52](https://github.com/jpmonette/feed/issues/52)
- RSS author is still \(again\) broken [\#50](https://github.com/jpmonette/feed/issues/50)
- writing feed as a stream of articles \[feature request\] [\#44](https://github.com/jpmonette/feed/issues/44)
- New line is not transformed to \<BR\> [\#42](https://github.com/jpmonette/feed/issues/42)
- I would like to provide some custom namespace for my item nodes [\#38](https://github.com/jpmonette/feed/issues/38)
- Missing 'type="image/\*"' attribute for image enclosures [\#37](https://github.com/jpmonette/feed/issues/37)
- How to append items to an existing RSS-2.0 Feed [\#33](https://github.com/jpmonette/feed/issues/33)
- Namespace prefix content on encoded is not defined [\#32](https://github.com/jpmonette/feed/issues/32)
- support for multiple enclosures in one item? [\#31](https://github.com/jpmonette/feed/issues/31)

**Merged pull requests:**

- add optional language field [\#86](https://github.com/jpmonette/feed/pull/86) ([zsolt-dev](https://github.com/zsolt-dev))
- Make `feed` option optional [\#85](https://github.com/jpmonette/feed/pull/85) ([Vinnl](https://github.com/Vinnl))
- Change html\_content to content\_html [\#81](https://github.com/jpmonette/feed/pull/81) ([leereamsnyder](https://github.com/leereamsnyder))
- Fix TypeScript declarations [\#73](https://github.com/jpmonette/feed/pull/73) ([lenovouser](https://github.com/lenovouser))

## [2.0.0](https://github.com/jpmonette/feed/tree/2.0.0) (2018-08-04)
[Full Changelog](https://github.com/jpmonette/feed/compare/1.1.0...2.0.0)

**Closed issues:**

- Items in feed not added image property [\#63](https://github.com/jpmonette/feed/issues/63)

**Merged pull requests:**

- We are moving to TypeScript! [\#72](https://github.com/jpmonette/feed/pull/72) ([jpmonette](https://github.com/jpmonette))
- Remove octal number from example [\#70](https://github.com/jpmonette/feed/pull/70) ([manniL](https://github.com/manniL))
- Push to version 1.1.1 [\#66](https://github.com/jpmonette/feed/pull/66) ([jpmonette](https://github.com/jpmonette))
- fix\(images\): Fixes image enclosures for items [\#65](https://github.com/jpmonette/feed/pull/65) ([zfoster](https://github.com/zfoster))
- add support for extensions in json1 [\#60](https://github.com/jpmonette/feed/pull/60) ([alx](https://github.com/alx))

## [1.1.0](https://github.com/jpmonette/feed/tree/1.1.0) (2017-06-03)
[Full Changelog](https://github.com/jpmonette/feed/compare/1.0.1...1.1.0)

**Closed issues:**

- \</link\> stripped out [\#53](https://github.com/jpmonette/feed/issues/53)
- "updated" broken [\#51](https://github.com/jpmonette/feed/issues/51)
- validateURL is not nice function [\#23](https://github.com/jpmonette/feed/issues/23)

**Merged pull requests:**

- Version 1.1.0 [\#58](https://github.com/jpmonette/feed/pull/58) ([jpmonette](https://github.com/jpmonette))
- Add Support for JSON Feed v1 [\#56](https://github.com/jpmonette/feed/pull/56) ([benmccormick](https://github.com/benmccormick))
- Add custom generator string options.generator [\#55](https://github.com/jpmonette/feed/pull/55) ([VarunBatraIT](https://github.com/VarunBatraIT))

## [1.0.1](https://github.com/jpmonette/feed/tree/1.0.1) (2017-04-02)
**Implemented enhancements:**

- Allow for manual setting of the feed updated date [\#14](https://github.com/jpmonette/feed/issues/14)
- Readme should mention missing stuff [\#3](https://github.com/jpmonette/feed/issues/3)
- Tests [\#2](https://github.com/jpmonette/feed/issues/2)
- Author fields in feed items? [\#1](https://github.com/jpmonette/feed/issues/1)

**Fixed bugs:**

- Forgot a "console.log" [\#5](https://github.com/jpmonette/feed/issues/5)

**Closed issues:**

- Cut a new release [\#47](https://github.com/jpmonette/feed/issues/47)
- RSS author tag for each post should contain only email [\#41](https://github.com/jpmonette/feed/issues/41)
- URL in repo description is a dead link [\#36](https://github.com/jpmonette/feed/issues/36)
- Lots of commits missing in npm [\#35](https://github.com/jpmonette/feed/issues/35)
- AppFog 404 Not Found [\#20](https://github.com/jpmonette/feed/issues/20)
- Generated Atom feed has a few problems according to validator [\#19](https://github.com/jpmonette/feed/issues/19)
- content encoding [\#17](https://github.com/jpmonette/feed/issues/17)
- TypeError: Object July 21, 1983 01:15:00 has no method 'toUTCString' [\#11](https://github.com/jpmonette/feed/issues/11)
- The code breaks when atom feed is requested [\#8](https://github.com/jpmonette/feed/issues/8)
- Author email and link should be optional [\#6](https://github.com/jpmonette/feed/issues/6)

**Merged pull requests:**

- Initial Babel migration commit [\#49](https://github.com/jpmonette/feed/pull/49) ([jpmonette](https://github.com/jpmonette))
- Resolves \#41 - Fix “author” tag based on W3 Validator [\#48](https://github.com/jpmonette/feed/pull/48) ([jpmonette](https://github.com/jpmonette))
- fixed the failing test due to date provided [\#45](https://github.com/jpmonette/feed/pull/45) ([parit](https://github.com/parit))
- Update package.json [\#43](https://github.com/jpmonette/feed/pull/43) ([f0rr0](https://github.com/f0rr0))
- Feed id is required. Demonstrate that in README [\#39](https://github.com/jpmonette/feed/pull/39) ([KyleAMathews](https://github.com/KyleAMathews))
- Support for the entry\#published attribute [\#34](https://github.com/jpmonette/feed/pull/34) ([benilovj](https://github.com/benilovj))
- Validation fixes [\#26](https://github.com/jpmonette/feed/pull/26) ([download13](https://github.com/download13))
- disable url validation [\#24](https://github.com/jpmonette/feed/pull/24) ([bewest](https://github.com/bewest))
- feed.item\(\) is deprecated [\#18](https://github.com/jpmonette/feed/pull/18) ([KyleAMathews](https://github.com/KyleAMathews))
- adding contributors and copyright for atom [\#12](https://github.com/jpmonette/feed/pull/12) ([shafan](https://github.com/shafan))
- Updates to better pass the W3C validator, and other improvements [\#10](https://github.com/jpmonette/feed/pull/10) ([smebberson](https://github.com/smebberson))
- Fixed iterator bug [\#9](https://github.com/jpmonette/feed/pull/9) ([brickcap](https://github.com/brickcap))
- here's my change to ensure array iteration works even if arrays have other properties [\#7](https://github.com/jpmonette/feed/pull/7) ([haszari](https://github.com/haszari))



\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*